import axios from 'axios'
import { unique } from '.'

// List processes
export const listProcesses = unique(async params => (await axios.get('/process/', { params })).data)

// List templates
export const listTemplates = listProcesses

// Retrieve a process details
export const retrieveProcess = unique(async id => (await axios.get(`/process/${id}/`)).data)

// Create a new process
export const createProcess = async payload => (await axios.post('/process/corpus/', payload)).data

// Update a process
export const updateProcess = async ({ id, payload }) => (await axios.patch(`/process/${id}/`, payload)).data

// Retry a process
export const retryProcess = unique(async id => (await axios.post(`/process/${id}/retry/`)).data)

// Delete a process
export const deleteProcess = unique(async id => await axios.delete(`/process/${id}/`))

// Start a process
export const startProcess = unique(async ({ id, payload }) => (await axios.post(`/process/${id}/start/`, payload)).data)

// List elements involved in a process
export const listProcessElements = unique(async ({ id, ...params }) => (await axios.get(`/process/${id}/elements/`, { params })).data)

// Create a template based on a process
export const createProcessTemplate = unique(async ({ id, payload }) => (await axios.post(`/process/${id}/template/`, payload)).data)

// Apply a process template on a process
export const applyProcessTemplate = unique(async ({ id, payload }) => (await axios.post(`/process/${id}/apply/`, payload)).data)

// Clear a process (remove all worker runs and templates)
export const clearProcess = unique(async id => await axios.delete(`/process/${id}/clear/`))

// Select elements with a worker activity failure on the process
export const selectProcessFailures = unique(async id => await axios.post(`/process/${id}/select-failures/`))

export const listProcessDatasets = unique(async ({ processId, ...params }) => (await axios.get(`/process/${processId}/datasets/`, { params })).data)

export const createProcessDataset = unique((processId, datasetId, payload) => axios.post(`/process/${processId}/dataset/${datasetId}/`, payload))

export const updateProcessDataset = unique((processId, datasetId, payload) => axios.patch(`/process/${processId}/dataset/${datasetId}/`, payload))

export const deleteProcessDataset = unique((processId, datasetId) => axios.delete(`/process/${processId}/dataset/${datasetId}/`))
