/* eslint-disable mocha/no-setup-in-describe */
import { assert } from 'chai'
import axios from 'axios'
import { setActivePinia, createPinia } from 'pinia'
import { createStore } from 'vuex'
import { actions, loadModules } from '@/store/index.js'
import { FakeAxios, StoreTestPlugin } from '../testhelpers.js'

// Global Vuex store that can be used to run tests against the entire store
const store = createStore({
  actions,
  modules: loadModules(),
  plugins: [StoreTestPlugin]
})
export default store

describe('store', () => {
  describe('reset', () => {
    let mock

    before('Setting up mocks', () => {
      mock = new FakeAxios(axios)
      setActivePinia(createPinia())
    })

    afterEach(() => {
      // Remove any handlers, but leave mocking in place
      mock.reset()
      store.reset()
    })

    after('Removing Axios mock', () => {
      // Remove mocking entirely
      mock.restore()
    })

    it('resets the store', async () => {
      await store.dispatch('reset', { exclude: ['auth'] })
      assert.deepStrictEqual(store.history, [
        { action: 'reset', payload: { exclude: ['auth'] } },
        { mutation: 'annotation/reset' },
        { mutation: 'classification/reset' },
        { mutation: 'corpora/reset' },
        { mutation: 'elements/reset' },
        { mutation: 'files/reset' },
        { mutation: 'navigation/reset' },
        { mutation: 'notifications/reset' },
        { mutation: 'process/reset' },
        { mutation: 'repos/reset' },
        { mutation: 'selection/reset' },
        { mutation: 'tree/reset' }
      ])
    })
  })

  require('./annotation.spec.js')
  require('./auth.spec.js')
  require('./classification.spec.js')
  require('./corpora.spec.js')
  require('./elements.spec.js')
  require('./files.spec.js')
  require('./navigation.spec.js')
  require('./process.spec.js')
  require('./repos.spec.js')
  require('./selection.spec.js')
  require('./tree.spec.js')
})
