import axios from 'axios'
import { assert } from 'chai'
import { useJobsStore, useNotificationStore, useSearchStore } from '@/stores'
import { FakeAxios, actionsCompletedPlugin, setUpTestPinia } from '../testhelpers'
import { documentsSample, jobsSample } from '../samples'

describe('search', () => {
  let mock, store, jobsStore, notificationStore

  before('Setting up mocks', () => {
    setUpTestPinia([actionsCompletedPlugin])
    mock = new FakeAxios(axios)
    store = useSearchStore()
    jobsStore = useJobsStore()
    notificationStore = useNotificationStore()
  })

  afterEach(() => {
    // Remove any handlers, but leave mocking in place
    mock.reset()
    store.$reset()
    jobsStore.$reset()
    notificationStore.$reset()
  })

  after('Removing Axios mock', () => {
    // Remove mocking entirely
    mock.restore()
  })

  describe('search', () => {
    it('searches in a corpus', async () => {
      mock.onGet('/corpus/corpusid/search/', { query: 'meh' }).reply(200, documentsSample)

      await store.search('corpusid', { query: 'meh' })

      assert.deepStrictEqual(store.documents, documentsSample)
    })

    it('handles errors', async () => {
      mock.onGet('/corpus/corpusid/search/', { query: 'meh' }).reply(500)

      await store.search('corpusid', { query: 'meh' })

      assert.deepStrictEqual(notificationStore.notifications, [
        {
          id: 0,
          type: 'error',
          text: 'Request failed with status code 500'
        }
      ])
    })
  })

  describe('indexCorpus', () => {
    it('reindexes a corpus', async () => {
      mock.onPost('/corpus/corpusid/index/', { drop: false }).reply(201, { drop: false })
      mock.onGet('/jobs/').reply(200, jobsSample)

      await store.indexCorpus('corpusid', { drop: false })
      await jobsStore.actionsCompleted()

      assert.deepStrictEqual(jobsStore.jobs, {
        jobid: jobsSample[0]
      })
    })
  })
})
